@@ -1,12 +1,20 @@
 #!/bin/bash
-# Copyright (C) 2000-2005 SWsoft. All rights reserved.
+#  Copyright (C) 2000-2006 SWsoft. All rights reserved.
 #
-# This file may be distributed under the terms of the Q Public License
-# as defined by Trolltech AS of Norway and appearing in the file
-# LICENSE.QPL included in the packaging of this file.
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
 # This script configures quota startup script inside VE
 #
@@ -25,6 +33,7 @@ if [ -z "$MAJOR" ]; then
 fi
 echo -e '#!/bin/sh
 start() {
+	[ -e "/dev/'${DEVFS}'" ] || mknod /dev/'${DEVFS}' b '$MAJOR' '$MINOR'
 	rm -f /etc/mtab >/dev/null 2>&1
 	echo "/dev/'${DEVFS}' / reiserfs rw,usrquota,grpquota 0 0" > /etc/mtab
 	mnt=`grep -v " / " /proc/mounts`
@@ -51,7 +60,7 @@ for RC in ${RCDIRS}; do
 done
 
 if [ -z "${RC}" ]; then
-	echo "Unable to find runlevel derectories"
+	echo "Unable to find runlevel directories"
 	exit 1
 fi
 
