@@ -1,12 +1,19 @@
 /*
- * Copyright (C) 2000-2005 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
  *
- * This file may be distributed under the terms of the Q Public License
- * as defined by Trolltech AS of Norway and appearing in the file
- * LICENSE.QPL included in the packaging of this file.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <stdlib.h>
@@ -18,7 +25,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <string.h>
-#include <asm/timex.h>
 #include <linux/vzcalluser.h>
 #include <wait.h>
 #include <termios.h>
@@ -247,7 +253,7 @@ int do_enter(vps_handler *h, envid_t veid, char *root)
 		if ((pid = fork()) == 0) {
 			char buf[64];
 			char *term;
-		        char *arg[] = {"bash",  "--login", "-i", NULL};
+		        char *arg[] = {"-bash", NULL};
 		        char *env[] = {"HOME=/", "HISTFILE=/dev/null",
 				"PATH=/bin:/sbin:/usr/bin:/usr/sbin:", NULL, NULL};
 			close(master);
