@@ -1,12 +1,19 @@
 /*
- * Copyright (C) 2000-2005 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
  *
- * This file may be distributed under the terms of the Q Public License
- * as defined by Trolltech AS of Norway and appearing in the file
- * LICENSE.QPL included in the packaging of this file.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <linux/unistd.h>
@@ -22,6 +29,13 @@
 #include "vzerror.h"
 #include "logger.h"
 
+#ifndef	CAP_SETVEID
+#define	CAP_SETVEID	29
+#endif
+#ifndef	CAP_VE_ADMIN
+#define	CAP_VE_ADMIN	30
+#endif
+
 #define CAPDEFAULTMASK	(CAP_TO_MASK(CAP_CHOWN)		| \
 	CAP_TO_MASK(CAP_DAC_OVERRIDE)			| \
 	CAP_TO_MASK(CAP_DAC_READ_SEARCH)		| \
@@ -146,7 +160,7 @@ void build_cap_str(cap_param *new, cap_param *old, char *buf, int len)
 	sprintf(sp--, "\"");
 }
 
-static int set_cap(int veid, cap_t mask, int pid)
+static int set_cap(envid_t veid, cap_t mask, int pid)
 {
 	struct __user_cap_header_struct header;
 	struct __user_cap_data_struct data;
@@ -177,7 +191,7 @@ static inline cap_t make_cap_mask(cap_t on, cap_t off)
  * @param cap		capability mask.
  * @return		0 on success.
  */
-int vps_set_cap(int veid, cap_param *cap)
+int vps_set_cap(envid_t veid, cap_param *cap)
 {
 	cap_t mask;
 
