@@ -1,12 +1,19 @@
 /*
- * Copyright (C) 2000-2005 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
  *
- * This file may be distributed under the terms of the Q Public License
- * as defined by Trolltech AS of Norway and appearing in the file
- * LICENSE.QPL included in the packaging of this file.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <stdlib.h>
@@ -331,10 +338,11 @@ int vps_postcreate(envid_t veid, fs_param *fs, tmpl_param *tmpl)
 	if (check_var(fs->root, "VE_ROOT is not set"))
                 return VZ_VE_ROOT_NOTSET;
 	dist_name = get_dist_name(tmpl);
-	if ((ret = read_dist_actions(dist_name, DIST_DIR, &actions)))
-		return ret;
+	ret = read_dist_actions(dist_name, DIST_DIR, &actions);
 	if (dist_name != NULL)
 		free(dist_name);
+	if (ret)
+		return ret;
 	if (actions.post_create == NULL) {
 		ret = 0;
 		goto err;
