@@ -1,12 +1,19 @@
 /*
- * Copyright (C) 2000-2005 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
  *
- * This file may be distributed under the terms of the Q Public License
- * as defined by Trolltech AS of Norway and appearing in the file
- * LICENSE.QPL included in the packaging of this file.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <stdlib.h>
@@ -20,8 +27,8 @@
 #include <sys/wait.h>
 #include <string.h>
 #include <sys/ioctl.h>
-#include <asm/timex.h>
 #include <linux/vzcalluser.h>
+#include <sys/personality.h>
 
 #include "vzerror.h"
 #include "res.h"
@@ -32,10 +39,20 @@
 #include "util.h"
 #include "script.h"
 #include "iptables.h"
+#include "readelf.h"
 
 #define ENVRETRY	3
 #define VZCTLDEV	"/dev/vzctl"
 
+#ifndef __NR_setluid
+#ifdef __ia64__
+#define __NR_setluid	1506
+#elif __x86_64__
+#define __NR_setluid	501
+#else
+#define __NR_setluid	511
+#endif
+#endif
 
 static int env_stop(vps_handler *h, envid_t veid, char *root, int stop_mode);
 
@@ -44,6 +61,28 @@ static inline int setluid(uid_t uid)
 	return syscall(__NR_setluid, uid);
 }
 
+#ifdef  __x86_64__
+static int set_personality(unsigned long mask)
+{
+	unsigned long per;
+
+	per = personality(0xffffffff) | mask;
+	logger(3, 0, "Set personality %#10.8x", per);
+	if (personality(per) == -1) {
+		logger(2, errno, "Unable to set personality PER_LINUX32");
+		return  -1;
+	}
+	return 0;
+}
+
+static int set_personality32()
+{
+	if (get_arch_from_elf("/sbin/init") != elf_32)
+		return 0;
+	return set_personality(PER_LINUX32);
+}
+#endif
+
 int vz_env_create_data_ioctl(vps_handler *h,
 	struct vzctl_env_create_data *data)
 {
@@ -55,7 +94,11 @@ int vz_env_create_data_ioctl(vps_handler *h,
 			sleep(1);
 		errcode = ioctl(h->vzfd, VZCTL_ENV_CREATE_DATA, data);
 	} while (errcode < 0 && errno == EBUSY && retry++ < ENVRETRY);
-
+#ifdef  __x86_64__
+	/* Set personality PER_LINUX32 for i386 based VPSes */
+	if (errcode >= 0)
+		set_personality32();
+#endif
 	return errcode;
 }
 
@@ -73,7 +116,11 @@ int vz_env_create_ioctl(vps_handler *h, envid_t veid, int flags)
 			sleep(1);
 		errcode = ioctl(h->vzfd, VZCTL_ENV_CREATE, &env_create);
 	} while (errcode < 0 && errno == EBUSY && retry++ < ENVRETRY);
-
+#ifdef  __x86_64__
+	/* Set personality PER_LINUX32 for i386 based VPSes */
+	if (errcode >= 0 && (flags & VE_ENTER))
+		set_personality32();
+#endif
 	return errcode;
 }
 
@@ -189,7 +236,6 @@ int vz_setluid(envid_t veid)
         return 0;
 }
 
-
 /*
  * Checks if sysfs needs to be enabled for this VPS.
  * Now we do that only for distributions from sysfs_dists.
@@ -219,6 +265,8 @@ static int sysfs_required(vps_res *res)
 	return 0;
 }
 
+
+
 #ifdef VE_FEATURE_SYSFS
 /* Kernel understands new style env. create struct - with features etc. */
 #define KERNEL_HAVE_ENV_CREATE_PARAM2
@@ -242,7 +290,7 @@ static int _env_create(vps_handler *h, envid_t veid, int wait_p, int err_p,
 	res = (vps_res *) data;
 	memset(&create_param, 0, sizeof(create_param));
 	create_param.iptables_mask = get_ipt_mask(res->env.ipt_mask);
-	logger(3, 0, "Set iptables mask %d", create_param.iptables_mask);
+	logger(3, 0, "Set iptables mask %#10.8x", create_param.iptables_mask);
 	env_create_data.veid = veid;
 	env_create_data.class_id = 0;
 	env_create_data.flags = VE_CREATE | VE_EXCLUSIVE;
@@ -252,6 +300,8 @@ static int _env_create(vps_handler *h, envid_t veid, int wait_p, int err_p,
 	if (sysfs_required(res))
 		create_param.feature_mask = VE_FEATURE_SYSFS;
 #endif
+	/* Close all fds  except std */
+	close_fds(0, wait_p, err_p, h->vzfd, -1);
 try:
 	ret = vz_env_create_data_ioctl(h, &env_create_data);
 	if (ret < 0) {
@@ -328,10 +378,8 @@ static int vz_real_env_create(vps_handler *h, envid_t veid, vps_res *res,
 		logger(0, errno, "Unable to fork");
 		return VZ_RESOURCE_ERROR;
 	} else if (pid == 0) {
-
 		if ((ret = vps_set_cap(veid, &res->cap)))
 			goto env_err;
-		close_fds(0, wait_p, err_p, h->vzfd, -1);
 		if (fn == NULL) {
 			ret = _env_create(h, veid, wait_p, err_p, (void *)res);
 		} else {
@@ -454,14 +502,15 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 	char *dist_name;
 	struct sigaction act;
 	vps_res *res = &param->res;
-	dist_actions *actions = NULL;
+	dist_actions actions;
 
-	actions = malloc(sizeof(*actions));
+	memset(&actions, 0, sizeof(actions));
 	dist_name = get_dist_name(&res->tmpl);
-	if ((ret = read_dist_actions(dist_name, DIST_DIR, actions)))
-		return ret;
+	ret = read_dist_actions(dist_name, DIST_DIR, &actions);
 	if (dist_name != NULL)
 		free(dist_name);
+	if (ret)
+		return ret;
 	if (check_var(res->fs.root, "VE_ROOT is not set"))
 		return VZ_VE_ROOT_NOTSET;
 	if (vps_is_run(h, veid)) {
@@ -498,12 +547,11 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 	fix_cpu(&res->cpu);
 	if ((ret = vz_env_create(h, veid, res, wait_p, err_p, fn, data)))
 		goto err;
-	if ((ret = vps_setup_res(h, veid, actions, &res->fs, param,
+	if ((ret = vps_setup_res(h, veid, &actions, &res->fs, param,
 		STATE_STARTING, skip, mod)))
 	{
 		goto err;
 	}
-
 	if (!(skip & SKIP_ACTION_SCRIPT)) {
 		snprintf(buf, sizeof(buf), VPS_CONF_DIR "%d.%s", veid,
 			START_PREFIX);	
@@ -520,7 +568,7 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 	if (close(wait_p[1]))
 		logger(0, errno, "Unable to close fd to start init");
 err:
-	free_dist_actions(actions);
+	free_dist_actions(&actions);
 	if (ret) {
 		int err;
 		/* Kill enviroment */
@@ -539,7 +587,8 @@ err:
 	if (ret) {
 		if (vps_is_run(h, veid))
 			env_stop(h, veid, res->fs.root, M_KILL);
-		vps_quotaoff(veid, &res->dq);
+		/* restore original quota values */
+		vps_set_quota(veid, &res->dq);
 		if (vps_is_mounted(res->fs.root))
 			vps_umount(h, veid, res->fs.root, skip);
 	}
@@ -707,7 +756,8 @@ int vps_stop(vps_handler *h, envid_t veid, vps_param *param, int stop_mode,
 		return ret;
 	mod_cleanup(h, veid, action, param);
 	if (!res->net.skip_route_cleanup)
-		run_net_script(veid, DEL, &ips, STATE_RUNNING);
+		run_net_script(veid, DEL, &ips, STATE_RUNNING,
+			param->res.net.skip_arpdetect);
 	ret = vps_umount(h, veid, res->fs.root, skip);
 	/* Clear VPS network configuration*/
 	ret = run_pre_script(veid, VPS_STOP);
